\name{age.max}
\alias{age.max}
\title{Upper age boundary function (posum)}
\description{Given a posum input data frame/list, this returns a function 
[amax(t)] the value of which is the upper age boundary of the juvenile populaiton surface at time t.}
\usage{ age.max(data) }

\arguments{
\item{data}{A data frame containing the following named variables:
   \item{y}{The stage population data. This may contain \code{NA}'s: 
            a feature whose prime function is to allow the user to 
            supply extra information about stage boundaries, if
            needed.}
   \item{stage}{Which stage each element of \code{y} relates to.}
   \item{a0}{The lower age boundary for this observation.}
   \item{a1}{The upper age boundary for this observation. \code{NA} 
             implies an adult stage. If an element is equal to the
             corresponding \code{a0} element then the corresponding
             \code{y} is taken as a direct observation of the population
             surface height (rather than the usual integral under it.)}
   \item{t}{Sample time for each observation.}
}
}

\details{The routine collects the data in the input dataframe relating to the 
upper age boundary of the juvenile population surface. This is either the 
lower, \code{a0}, boundary data for the adult stage, or if there is no adult 
stage, the upper, \code{a1}, boundary of the last juvenile stage. (`Adult' is 
here used to mean a final stage of indeterminate duration, if the final adult 
stage is of fixed duration then it is treated as a juvenile stage). Having 
collected the data then it is interpolated in time using a cubic spline, 
filtered using a version of Hyman's (1983) method to ensure that the function 
never increases by more than one day per day (this restriction is simply a 
biological fact!).
}
\value{A function is returned. The returned function returns the population 
surface upper age boundary at each time supplied in its array argument.
}
\references{
Hyman (1983) SIAM J. Sci. Stat. Comput. 4(4):645-654
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{} 

\seealso{   
\code{\link{cm.splinefun}},
\code{\link{hyman.filter}},
\code{\link{spl.coef.conv}},
\code{\link{stage.bound}},
}

\examples{
data<-population.data(fam="p",adult=TRUE) #simulate dataframe
amax<-age.max(data)   # get upper juvenile age boundary function
seq(min(data$t),max(data$t),length=100)->times
plot(times,amax(times),type="l",main="Demonstration of age.max (posum)")
data<-population.data(adult=FALSE) #simulate dataframe (no adults)
amax<-age.max(data)   # get upper juvenile age boundary function
plot(times,amax(times),type="l",main="Demonstration of age.max (posum)")
}
\keyword{models} \keyword{smooth} \keyword{regression}%-- one or more ..




\name{cm.splinefun}
\alias{cm.splinefun}
\title{Interpolating spline subject to co-monotonic filtering}
\description{Returns an interpolating spline function that has had its 
coefficients  filtered using Hyman's (1983) algorithm for ensuring 
co-monotonicity. The filter is slightly modified to enable the user to 
set an upper limit on the gradient of the interpolant. The routine is a 
modification of the R base \code{splinefun} routine.
}
\usage{cm.splinefun(x, y = NULL, method = "fmm",gulim=0)
}
\arguments{
\item{x}{ A set of x values}
\item{y}{y values corresponding to the x values. These y values will be 
interpolated to produce a function of x passing through the x,y points.} 
\item{method}{end condition method, can be \code{"natural"}, \code{"periodic"}
 or \code{"fmm"} - see \code{\link{splinefun}} for details}
\item{gulim}{if this is non-zero then it is taken as the upper limit on the 
gradient of the returned spline function (obviously, this can't be less than 
the maximum gradient of any line segment joining adjacent points). }
}

\details{ The code is modified from \code{splinefun}, and directly calls
compiled routines \code{spline_coef()} and \code{spline_eval()} from the 
\code{R} base package. The method is as follows:
\item{1.}{ Call \code{spline_coef()} to get the coefficients of the 
interpolating cubic spline through \code{x,y}. Let the returned gradients
w.r.t. \code{x} at \code{x,y} be \code{b}. }
\item{2.}{ Transform \code{y} to \code{y-x*gulim} and \code{b} to 
\code{b-gulim}.}
\item{3.}{Apply Hyman's (1983) co-monotonicity filter to the transformed \code{x,y,b} data. Hyman's Algorithm works on the Hermite polynomial representation,
so this is all that's needed. Modified \code{b} values are returned.}
\item{4.}{Untransform the \code{y,b} values. \code{y} becomes \code{y+x*gulim}
and code{b} becomes \code{b+gulim}.}
\item{5.}{Find the remaining spline coefficients consistent with the filtered,
\code{x,y,b} values by calling \code{spl.coef.conv}. }
\item{6.}{Return a function that calls \code{spline.eval()} with the filtered 
coefficients in order to return the evaluated fitted spline.}

The \code{y,b} transformation trick is used to turn the monotonicity method 
into a gradient limit method. 
}
\value{ The function returns a function which will return the filtered 
interpolant evaluated at each value of its array argument.
}
\references{
Hyman (1983) SIAM J. Sci. Stat. Comput. 4(4):645-654
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{The routine does not check that the upper gradient limit is possible
given the data to be interpolated: the user must do this!} 

\seealso{   
\code{\link{age.max}},
\code{\link{hyman.filter}},
}

\examples{

# simple co-monotonic example

x<-c(0,0.2,0.4,3,3.5,4,5,6,7.2,8,10)
y<-c(0,0.1,0.3,0.6,0.3,0.2,0.1,0.099,0.099,0.094,0.01)
xx<-seq(0,10,length=100)
normal.spl<-splinefun(x,y)
plot(xx,normal.spl(xx),type="l",col=2,main="co-monotonic spline demonstration")
cm.spl<-cm.splinefun(x,y)
lines(xx,cm.spl(xx),col=3)
points(x,y)

# gradient limiting example

x<-0:9
y<-c(1,0,2,1,4,3,6,5,8,7)
normal.spl<-splinefun(x,y)
xx<-seq(0,9,length=100)
plot(xx,normal.spl(xx),type="l",col=2,main="gradient limited spline demonstration")
cm.spl<-cm.splinefun(x,y,gulim=3)
lines(xx,cm.spl(xx),col=3)
points(x,y)
}
\keyword{models} \keyword{smooth} \keyword{regression}%-- one or more ..









\name{simulated surfaces}
\alias{death.surface}
\alias{population.surface}
\title{Simulated total population/death-rate surface (posum)}
\description{ Produces and plots the total death rate surface or population 
surface corresponding to the model specified by \code{\link{pcdr}} and 
code{\link{rec}}.}
\usage{ death.surface(a1,t1,m,con=FALSE)

population.surface(a1,t1,m,con=FALSE)}
\arguments{
\item{a1}{surfaces run from age 0 to age \code{a1}.}
\item{t1}{surfaces run from time 0 to time \code{t1}.}
\item{m}{surfaces will be on an m by m grid.}
\item{con}{\code{TRUE} for a contour plot, \code{FALSE} for a perspective 
plot.}
}

\details{ Given the model specified in functions \code{rec} and \code{pcdr}, 
these functions make use of functions \code{population} and \code{survival}
to produce total death rate (i.e. numbers per unit age interval dying per 
unit time) and population (numbers per unit age interval) surfaces.
}
\value{ A three item list the elements of which are suitable for plotting 
with \code{persp} or \code{contour}:
\item{a}{array of ages.}
\item{t}{array of times.}
\item{pop/death}{matrix of populations or total deaths at all \code{a}, 
code{t} combinations.}
}
\references{
\url{http://www.ruwpa.st-and.ac.uk/simon.html}
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{} 

\seealso{   
\code{\link{pcdr}},
\code{\link{population}},
\code{\link{rec}},
\code{\link{survival}},
}

\examples{
op<-par(mfrow=c(2,2))
pop<-population.surface(30,100,30)
death<-death.surface(30,100,30)
# corresponding per capita death rate ....
pcdr<-death
pcdr$death<-pcdr$death/pop$pop
persp(pcdr$a,pcdr$t,pcdr$death,theta=60)
population.surface(30,100,30,con=TRUE)
par(op)
}
\keyword{models} \keyword{smooth} \keyword{regression}%-- one or more ..




\name{hyman.filter}
\alias{hyman.filter}
\title{Co-monotonic filtering of cubic Hermite polynomials}
\description{ Filters the coefficients of an interpolating set of cubic 
Hermite polynomials to ensure co-monotonicity of the interpolant. Usually the 
original coefficients will be chosen so that the original interpolant is a 
cubic spline. Hyman's algorithm works with a set of sufficient conditions for
monotonicity so these are slightly more restrictive than is absolutely 
necessary.
}
\usage{hyman.filter(z)
}
\arguments{
\item{z}{ A list or dataframe containing at least the following:
\item{x,y}{set of x,y points that are to be interpolated - interpolant will 
be a function of x.}
\item{b}{gradients of the interpolant w.r.t. x at the x values. It is these 
values that will be modified to ensure co-monotonicity. }
}
If \code{z} has other elements, they will be ignored.
}

\details{ Basically limits on allowable values of \code{b} can be obtained 
from looking at the gradients of the piecewise linear interpolant through 
\code{x,y}: see Hyman (1983) for full details.
}
\value{ Returns the input dataframe/list \code{z} with array \code{b} modified 
to ensure co-monotonicity of the cubic Hermite interpolant defined by 
\code{x,y,b}.
}
\references{
Hyman (1983) SIAM J. Sci. Stat. Comput. 4(4):645-654
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{} 

\seealso{   
\code{\link{cm.splinefun}},\code{\link{spl.coef.conv}}
}

\examples{
# example partly modified from cm.splinefun
x<-0:9
y<-c(0,0,2,2,4,4,5,6,7,7)
normal.spl<-splinefun(x,y)
xx<-seq(0,9,length=100)
plot(xx,normal.spl(xx),type="l",col=2,main="Hyman filter demonstration")
n<-length(y)
z <- .C("spline_coef", method = as.integer(2), n = n, 
        x = as.double(x), y = as.double(y), b = double(n), c = double(n), 
        d = double(n),e = double(0), PACKAGE = "base")
z<-hyman.filter(z) # filter gradients for co-monotonicity
z<-spl.coef.conv(z) # force other coefficients to consistency
cm.spl<-function(x) { .C("spline_eval", z$method, length(x), x = as.double(x), 
            y = double(length(x)), z$n, z$x, z$y, z$b, z$c, z$d, 
            PACKAGE = "base")$y}
lines(xx,cm.spl(xx),col=3)
points(x,y)
}
\keyword{models} \keyword{smooth} \keyword{regression}%-- one or more ..









\name{posum simulation}
\alias{pcdr}
\alias{rec}
\title{Simulating Population Surface Models}
\description{Routines that specify per capita death rate and recruitment functions for
simulating population surface data}
\usage{pcdr(a,t)

rec(t)
}
%- maybe also `usage' for other objects documented here.
\arguments{
\item{a}{array of ages at which per capita death rates is required.}
\item{t}{array of times at which per capita death rates or recruitment rates 
are required.}
}

\details{ These functions are called by routines \code{survival} and 
\code{population} in order to calculate the population per unit age interval 
that they imply at any given age and time. The user should modify these
functions in order to simulate from a different model. Note that they
take array arguments.
}
\value{ The functions returns arrays of recruitment rates or per capita death 
rates at the specified times or ages and times.
}
\references{
\url{http://www.ruwpa.st-and.ac.uk/simon.html}
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{} 

\seealso{   
\code{\link{death.surface}},
\code{\link{population}},
\code{\link{population.data}},
\code{\link{population.surface}},
\code{\link{sim.age.bound}},
\code{\link{survival}},
}

\examples{
old.pcdr<-pcdr;old.rec<-rec
pcdr<-function(a,t) {0*a+0.01} # constant pcdr function
rec<-function(t) {r<-t;r[t<0]<-1;r[t>=0]<-exp(-0.02*t[t>=0]);r} 
population.surface(10,10,30,con=TRUE)
death.surface(10,10,30,con=TRUE) 
rec<-old.rec;pcdr<-old.pcdr
}
\keyword{models} \keyword{smooth} \keyword{regression}%-- one or more ..




\name{Simulate posum data}
\alias{population.data}
\alias{sim.age.bound}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Population Surface Data Simulation}
\description{ \code{population.data} simulates stage structured population data from the 
model specified by \code{rec} and \code{pcdr}. Stages are really age classes, with the (lower) age 
boundaries specified in \code{sim.age.bound}.}

\usage{
population.data(t=(0:20)*5,ns=11,sc=1,fam="n",adult=FALSE)

sim.age.bound(stage,t)
}
%- maybe also `usage' for other objects documented here.
\arguments{
\item{t}{ The array of sample times at which simulated data are required (\code{population.data}) 
or the array of times at which stage age boundaries are required (\code{sim.age.bound}).} 
\item{ns}{The number of stages.}
\item{sc}{The scale parameter for the noise to be added to the data.}
\item{fam}{Specifies the noise family as one of \code{"n"}, \code{"p"}, or \code{"g"}, 
for normal, Poisson or gamma distributions.}
\item{adult}{\code{TRUE} to simulate an adult final stage (i.e. indeterminate duration), 
\code{FALSE} otherwise. }
\item{stage}{which stage the lower age boundary is required for.}
}

\details{ Stage populations are obtained by integrating the populaiton surface model given by
\code{population} (and based on \code{pcdr} and \code{rec}) between the age limits specified in 
\code{sim.age.bound}. Noise is added according to the specified distribution and scale parameter.
Integration is performed numerically using the trapezoidal rule.}

\value{ \code{sim.age.bound} returns an array of stage lower age boundaries.

\code{population.data} returns a list object suitable for input to \code{posum}. The items in 
this list are:
\item{y}{array of simulated stage populations.}
\item{a0,a1}{lower and upper age boundaries corresponding to the data in \code{y}.}
\item{t}{sample times corresponding to data in \code{y}.}
\item{stage}{stage index corresponding to data in \code{y}.}
}
\references{
\url{http://www.ruwpa.st-and.ac.uk/simon.html}
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{} 

\seealso{   
\code{\link{death.surface}},
\code{\link{pcdr}},
\code{\link{population}},
\code{\link{population.surface}},
\code{\link{rec}},
\code{\link{survival}},
}

\examples{
data<-population.data(fam="p",adult=TRUE) #simulate data
b<-posum(data,fam="p")
op<-par(mfrow=c(2,2))
posum.plot(b)
plot(fitted(b),residuals(b))
plot(data$y,fitted(b))
par(mfrow=c(3,4))
posum.stage.plot(b)
posum.stage(b,lo=1,hi=4)
rm(data,b)
par(op)
}
\keyword{models} \keyword{smooth} \keyword{regression}%-- one or more ..




\name{posum}
\alias{posum}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Population Surface Model Fitting}
\description{ This routine fits a population surface model or death rate surface model to age structured population data. The routine relies on mgcv 0.8.2 or above.}
\usage{
posum(data,constrain=TRUE,fam="n",jk=50,ak=10,fk=5,rk=10,
      options=posum.options(),control=gam.control(),model.type=1)
}
%- maybe also `usage' for other objects documented here.
\arguments{
\item{data}{A data frame containing the following named variables:
   \item{y}{The stage population data. This may contain \code{NA}'s: 
            a feature whose prime function is to allow the user to 
            supply extra information about stage boundaries, if
            needed.}
   \item{stage}{Which stage each element of \code{y} relates to.}
   \item{a0}{The lower age boundary for this observation.}
   \item{a1}{The upper age boundary for this observation. \code{NA} 
             implies an adult stage. If an element is equal to the
             corresponding \code{a0} element then the corresponding
             \code{y} is taken as a direct observation of the population
             surface height (rather than the usual integral under it.)}
   \item{t}{Sample time for each observation.}
}
 \item{constrain}{Should positive death rate, positive population constraints 
on the model be imposed?}
 \item{fam}{Which error distribution to use. \code{"n"} for normal, 
    \code{"p"} for Poisson or \code{"g"} for gamma. (Note that link is always
     identity - nothing else makes sense for these models.) }
\item{jk}{The maximum number of parameters to use to represent the juvenile
          population surface. Actual effective degrees of freedom will be 
         chosen by mgcv as part of model fitting. }
\item{ak}{The maximum number of parameters to use to represent the adult
          population surve. Actual effective degrees of freedom will be 
         chosen by mgcv as part of model fitting.}
\item{fk}{basis dimension to use for initial age structure for type 2 models. }
\item{rk}{basis dimension to use for recruitment function for type 2 models.}
 \item{options}{ A list of options controlling numerical details of the 
           calculations. See \code{\link{posum.options}}. }
 \item{control}{ A \code{gam} fit control object: see 
           \code{\link{gam.control}} for details.}
\item{model.type}{Set to code{1} for a population surface model, in which the 
smoothness assumptions relate to the population per unit age interval surface,
 and death rates are obtained by differentiation of the fitted population 
surface. Set to code{2} for a death rate surface model, in which recruitment 
rate, inital population structure and total death rate surface are the things 
assumed smooth. In the latter case the population surface is obtained from 
the recruitment or initial population functions after subtraction of a 
suitable integral under the death rate surface.}
}

\details{ The code is based on setting up population surface/ death surface 
 models as special versions of generalized additive models and then fitting 
these using the GAM routines provided by package \code{mgcv}. 

Model type 1 is based on estimating the population per unit age interval surface 
as a smooth function of age and time and is quite quick. Model type 2 estimates 
the total death rate surface as a smooth function of age and time, the birth rate 
as a smooth function of time, and the initial populaiton per unit age inteval as 
a smooth function of age. Type 2 model are much slower, but can produce better 
results if recruitment varies rather fast in relation to the variation in death rate.  

}
\value{ The function returns a \code{gam} object, that can be used with most 
of the standard \code{gam} handling routines provided in \code{mgcv}. In 
addition it has some extra elements: 
\item{amax.fn}{ A function returning the age at the upper boundary of the 
population surface. This is based on the user supplied age boundary data, 
interpolated using a cubic spline filtered using a modification of Hyman's 
algorithm in order to ensure a gradient with respect to time less than or 
equal to one.}
\item{adults}{\code{TRUE} if adults present in data, \code{FALSE} if not.}
\item{data}{The input data frame.}
\item{options}{The input options.}

}
\references{

Gu and Wahba (1991) Minimizing GCV/GML scores with multiple smoothing parameters via
the Newton method. SIAM J. Sci. Statist. Comput. 12:383-398


Wood (2000) Modelling and Smoothing Parameter Estimation 
with Multiple 
   Quadratic Penalties. JRSSB 62(2):413-428

Wood (2003) Thin Plate Regression Splines in press JRSSB
 
\url{http://www.ruwpa.st-and.ac.uk/simon.html}
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{} 

\seealso{   
\code{\link{age.max}},
\code{\link{cm.splinefun}},
\code{\link{death.surface}},
\code{\link{hyman.filter}},
\code{\link{pcdr}},
\code{\link{population}},
\code{\link{population.data}},
\code{\link{population.surface}},
\code{\link{posum.atplot}},
\code{\link{posum.check}},
\code{\link{posum.con}},
\code{\link{posum.fit}},
\code{\link{posum.options}},
\code{\link{posum.plot}},
\code{\link{posum.stage}},
\code{\link{posum.stage.plot}},
\code{\link{posum.X}},
\code{\link{rec}},
\code{\link{sim.age.bound}},
\code{\link{spl.coef.conv}},
\code{\link{stage.bound}},
\code{\link{survival}},
}

\examples{
data<-population.data(fam="p",adult=TRUE) #simulate data
b<-posum(data,fam="p")
op<-par(mfrow=c(2,2))
posum.plot(b)
plot(fitted(b),residuals(b))
plot(data$y,fitted(b))
par(mfrow=c(3,4))
posum.stage.plot(b)
posum.stage(b,lo=1,hi=4)
rm(data,b)
par(op)
}
\keyword{models} \keyword{smooth} \keyword{regression}%-- one or more ..




\name{posum.X}
\alias{posum.X}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Obtain model matrix for a posum model}
\description{ Given a posum input dataframe and a \code{gam} object set up to 
provide bases for the components of the posum model, this routine produces 
the posum model matrix: the main part of this is integrating under the 
populaiton surface in order to get the matrix mapping the parameters to
the stage populaiton data. The routine is called by \code{posum}, rather
than directly by the user.}
\usage{
posum.X(data,b,ni=10)
}
%- maybe also `usage' for other objects documented here.
\arguments{
\item{data}{A data frame containing the following named variables:
   \item{y}{The stage population data. This may contain \code{NA}'s: 
            a feature whose prime function is to allow the user to 
            supply extra information about stage boundaries, if
            needed.}
   \item{stage}{Which stage each element of \code{y} relates to.}
   \item{a0}{The lower age boundary for this observation.}
   \item{a1}{The upper age boundary for this observation. \code{NA} 
             implies an adult stage. If an element is equal to the
             corresponding \code{a0} element then the corresponding
             \code{y} is taken as a direct observation of the population
             surface height (rather than the usual integral under it.)}
   \item{t}{Sample time for each observation.}
}
\item{b}{a \code{gam} object containing the information specifying the 
basis for the populaiton surface and optionally the adults.}
\item{ni}{the number of points to use in each (trapezoidal rule) stage 
integration - in practice controlled via option \code{n.int} in 
call to \code{posum.options} as part of \code{posum} call.}
}

\details{ \code{posum} sets up a population surface model as a \code{gam} using the 
functions provided in library \code{mgcv}, however since the response data for the
posum models consist of integrals of the population surface it is necessary to create a 
special \code{gam} design matrix to take account of this. This is done by passing a 
\code{gam} object to \code{posum.X}, which then uses it to call \code{predict.gam} with 
\code{type="lpmatrix"} in order to get the matrix mapping the parameters to the populaiton 
surface at a fine mesh of points appropriately spread over the population surface. 
Summing rows of this matrix in the right way yields the desired model matrix.

}
\value{ The function returns the required model matrix.}

}
\references{
 
\url{http://www.ruwpa.st-and.ac.uk/simon.html}
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{} 

\seealso{   
\code{\link{posum}},
\code{\link{posum.con}},
\code{\link{posum.options}},
}

\keyword{models} \keyword{smooth} \keyword{regression}%-- one or more ..




\name{posum.atplot}
\alias{posum.atplot}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Check posum age boundaries}
\description{ Produces a plot illustrating the stage boundaries assumed used by
posum, along with sampling times, which stages have data at which sample times,
and the location of any point estimates of surface height.}

\usage{
posum.atplot(data,n.grid)
}
%- maybe also `usage' for other objects documented here.
\arguments{
\item{data}{A data frame containing the following named variables:
   \item{y}{The stage population data. This may contain \code{NA}'s: 
            a feature whose prime function is to allow the user to 
            supply extra information about stage boundaries, if
            needed.}
   \item{stage}{Which stage each element of \code{y} relates to.}
   \item{a0}{The lower age boundary for this observation.}
   \item{a1}{The upper age boundary for this observation. \code{NA} 
             implies an adult stage. If an element is equal to the
             corresponding \code{a0} element then the corresponding
             \code{y} is taken as a direct observation of the population
             surface height (rather than the usual integral under it.)}
   \item{t}{Sample time for each observation.}
}
\item{n.grid}{ The number of time points to use for plotting the age boundaries - more for
a smoother curve.}
}

\details{ Age boundaries are shown as continuous black curves. Red lines indicate each 
sample-time-stage combination for which there is an observation. Adult observations are 
shown by red lines not terminating at a black stage boundary curve. Locations of point 
observations of the surface height are marked by red circles.
}
\value{ The function produces a plot.
}
\references{
\url{http://www.ruwpa.st-and.ac.uk/simon.html}
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{} 

\seealso{   
\code{\link{age.max}},
\code{\link{cm.splinefun}},
\code{\link{hyman.filter}},
\code{\link{posum.check}},
\code{\link{stage.bound}},
}

\examples{
data<-population.data(fam="p",adult=TRUE) #simulate data
posum.atplot(data)
}
\keyword{models} \keyword{smooth} \keyword{regression}%-- one or more ..











\name{posum.check}
\alias{posum.check}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Check a posum input dataframe}
\description{Performs simple checks on the input data for posum: mostly just checking that there are 
no missing values where they are not allowed. Returns \code{TRUE} if dataframe contains adult data, \code{FALSE} 
otherwise.}

\usage{
posum.check(data)
}
%- maybe also `usage' for other objects documented here.
\arguments{
\item{data}{A data frame containing the following named variables:
   \item{y}{The stage population data. This may contain \code{NA}'s: 
            a feature whose prime function is to allow the user to 
            supply extra information about stage boundaries, if
            needed.}
   \item{stage}{Which stage each element of \code{y} relates to.}
   \item{a0}{The lower age boundary for this observation.}
   \item{a1}{The upper age boundary for this observation. \code{NA} 
             implies an adult stage. If an element is equal to the
             corresponding \code{a0} element then the corresponding
             \code{y} is taken as a direct observation of the population
             surface height (rather than the usual integral under it.)}
   \item{t}{Sample time for each observation.}
}
}

\details{ Missing stage populaiton data is allowed in the input dataframe to \code{posum}, but missing age
 boundaries and sample times are not (except for upper boundary of an adult stage). This routine checks an input
datafraem for illegal missing values.}

\value{ Returns \code{TRUE} if \code{data} contains information on an adult (indeterminate duration) stage, 
\code{FALSE} otherwise. Will stop with an error if illegal missing values are encountered.

}
\references{
\url{http://www.ruwpa.st-and.ac.uk/simon.html}
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{} 

\seealso{   
\code{\link{posum}},

}

\examples{
data<-population.data(fam="p",adult=TRUE) #simulate data
posum.check(data)
}
\keyword{models} \keyword{smooth} \keyword{regression}%-- one or more ..




\name{posum.con}
\alias{posum.con}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Population surface model constraint generation}
\description{ Produces the linear inequality constraints that ensure 
(approximate) non-negativeness of model population and death rates. 
This routine is called by \code{posum} during model set up in order 
to generate the required constraints. 
}
\usage{
posum.con(b,amax,data,fdi=0.01,m=40,adults=FALSE)
}
%- maybe also `usage' for other objects documented here.
\arguments{
\item{b}{A \code{gam} object containing the bases used to represent the population 
surface and  adults if present.}
\item{amax}{A function returning the upper age boundary of the populaiton surface 
at any time. Usually this will have been generated by routine \code{age.max}.}
\item{data}{A data frame containing the following named variables:
\item{y}{The stage population data. This may contain \code{NA}'s: 
            a feature whose prime function is to allow the user to 
            supply extra information about stage boundaries, if
            needed.}
\item{stage}{Which stage each element of \code{y} relates to.}
\item{a0}{The lower age boundary for this observation.}
\item{a1}{The upper age boundary for this observation. \code{NA} 
             implies an adult stage. If an element is equal to the
             corresponding \code{a0} element then the corresponding
             \code{y} is taken as a direct observation of the population
             surface height (rather than the usual integral under it.)}
\item{t}{Sample time for each observation.}
}
\item{fdi}{coefficient controlling the size of finite difference interval to use for
numerical calculation of derivatives required in constraints. Constraints are applied
at each point on a regular \code{m} by \code{m} grid over the age time plane. 
The minimum of the grid spacing in age and time is found, and multiplied by 
\code{fdi} to get the finite difference interval to use.}
\item{m}{constraints are applied on an \code{m} by \code{m} grid over the model age 
time plane.}
\item{adults}{set to \code{TRUE} if adult constraints are required, \code{FALSE} 
otherwise.}
}

\details{ Let \eqn{ n }{n} be the population per unit age interval. If 
\eqn{ n \ge 0 }{n>=0} along the upper age boundary of the surface, and final sample 
time boundary of the surface, and if:
\eqn{ \partial n/\partial a+\partial n/\partial t \le 0 }{dn/da+dn/dt <=0} everywhere,
 then n will be positive and will not imply negative death rates. These constraints 
are applied in practice on a relatively fine mesh across the age-time domain of 
\eqn{ n }{n}. 

If there is an adult stage \eqn{ a }{a} then additional constraints are required 
(partly in replacement for the surface non-negativity constraint at the upper age 
boundary). The adult stage is governed by:
\eqn{ da/dt = R(t) - m(t) a(t) }{da/dt=R(t)-m(t)a(t)}
where \eqn{ m }{m} is per capita death rate and \eqn{ R(t) }{R(t)} is recruitment to the 
adult stage. 
\eqn{ R(t)= n(T)[1-\partial T/\partial t] }{R(t)=n(T)[1-dT/dt]} where \eqn{ T }{T} is 
the age at the upper boundary of the surface. We require that \eqn{ a \ge 0 }{a>=0} and 
\eqn{ R(t)-da/dt\ge 0 }{R(t)-da/dt >=0} to ensure non-negativeness of the adult 
population and its death rate respectively. Once again, these constraints are 
applied at on a fine time mesh in practice. 

The routine is called by \code{posum}, rather than being used directly: 
\code{fdi} and \code{m} would usually be set using \code{posum.options} in a 
call to \code{posum}. 
}
\value{ A matrix \code{C} is returned such that if 
\code{C b$coeff>=0} 
then the 
(approximate) constraints are met. 
}
\references{
\url{http://www.ruwpa.st-and.ac.uk/simon.html}
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{} 

\seealso{   
\code{\link{posum}},
\code{\link{posum.options}}
}


\keyword{models} \keyword{smooth} \keyword{regression}%-- one or more ..




\name{posum.fit}
\alias{posum.fit}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Fitting posum models}
\description{ This routine fits a population surface model to age structured
population data. It is not usually called directly, but is rather a service 
routine for \code{posum}. It is a modification of \code{gam.fit}.}
\usage{
posum.fit(G, start = NULL, etastart = NULL, mustart = NULL, family = gaussian(), 
    control = gam.control(), nb.iter = NULL) 
}
%- maybe also `usage' for other objects documented here.
\arguments{
\item{G}{A modified version of the object returned by calls to \code{gam.setup} and \code{GAMsetup}.}
\item{start}{optional parameter start values.}
\item{etastart}{optional linear predictor start values.}
\item{mustart}{optional fitted value start values.}
\item{family}{family object - actually only \code{gaussian}, \code{poisson} or \code{gamma} with identity 
links, should really be used.}
\item{control}{control list for fitting - see \code{gam.control}.}
\item{nb.iter}{Don't use!}
}

\details{ Essentially a GAM IRLS fitting loop, but with the \code{mgcv} call followed by a call to 
\code{pcls} to fit subject to the constraints. Also, fitted values are reset to a small number if too small, to avoid negative numbers.}

\value{ Returns fitted mopdel object.}
}
\references{
\url{http://www.ruwpa.st-and.ac.uk/simon.html}
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{} 

\seealso{   
\code{\link{posum}},
\code{\link{mgcv}}
}


\keyword{models} \keyword{smooth} \keyword{regression}%-- one or more ..




\name{posum.options}
\alias{posum.options}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Setting posum options}
\description{ Allows setting of some coefficients in \code{posum}.}
\usage{
posum.options(con.mesh=40,fdi=0.01,n.int=10,m.dint=3)
}
%- maybe also `usage' for other objects documented here.
\arguments{
\item{con.mesh}{the non-negativity constraints will be applied on a 
\code{con.mesh} by \code{con.mesh} mesh over the age time plane.}
\item{fdi}{determines the finite difference interval to use when applying 
constraints or calcualting death rates. Typically an output time/age step is
 determined and the finite difference interval set to \code{fdi} multiplied 
by this. For example when creating constraints the smaller of the age and time 
interval of the constraint mesh is taken and multiplied by \code{fdi} to get 
the finite difference interval to use for death rate calcualtions.}
\item{n.int}{How many mesh points to use per stage when integrating under the 
population surface to set up the model matrix.}
\item{m.dint}{This is a multiplier used to find the integration timestep to 
use when integrating under the death rate surface. The time step is obtained 
by dividing the maximum age seen in the data by m.dint*d.int*ns, where ns is 
the number of stages being modelled. This interval is used as the target 
timestep, although the actual timestep is chosen so that a whole number of 
intervals is used for the integration.}
}
\keyword{models} \keyword{smooth} \keyword{regression}


\value{ A named list of the input arguments.}

\references{
\url{http://www.ruwpa.st-and.ac.uk/simon.html}
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{} 

\seealso{   
\code{\link{posum.con}},
\code{\link{posum}},
\code{\link{posum.X}},

}





\name{posum.plot}
\alias{posum.plot}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Default posum model plotting}
\description{Produces population and death rate surface plots from a fitted
model object as produced by \code{posum}.}  

\usage{
posum.plot(b,fdi=b$options$fdi,m=b$options$con.mesh,con=FALSE,theta=60)
}
%- maybe also `usage' for other objects documented here.
\arguments{
\item{b}{Fitted model object as produced by \code{posum} (basically a modified \code{gam} 
object).}
\item{fdi}{parameter used to control finite difference interval length used to obtain 
derivatives dequired for death rate estimation. The population and death surfaces are 
evaluated on a regular \code{m} by \code{m} mesh. The smaller of the age and time intervals 
of this mesh is multiplied by \code{fdi} to get the required finite difference interval.}
\item{m}{population and death rate surfaces are evaluated and plotted on regular \code{m}
by \code{m} meshes.}
\item{con}{if \code{TRUE} then contour plots are produced, otherwise perspective plots.}
\item{theta}{angle from which to view perspective plot.}
}

\details{Evaluation uses calls to \code{predict.gam} to evaluate the model on a regular grid.
Slightly shifted grids are used to obtain the death rates by finite differencing. 
}
\value{ Two plots are produced.}

\references{
\url{http://www.ruwpa.st-and.ac.uk/simon.html}
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{} 

\seealso{   
\code{\link{posum}},
\code{\link{posum.plot}},
\code{\link{posum.stage.plot}},
}

\examples{
data<-population.data(fam="p",adult=TRUE) #simulate data
b<-posum(data,fam="p")
op<-par(mfrow=c(2,2))
posum.plot(b)
posum.plot(b,con=TRUE)
par(op)
}
\keyword{models} \keyword{smooth} \keyword{regression}%-- one or more ..




\name{posum.pop.matrix}
\alias{posum.pop.matrix}
\alias{posum.death.matrix}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Population/Death surface evaluation matrices}
\description{ These two routines find the matrices mapping the model 
parameter vector to either the population surface or the total death 
rate surface. \code{posum.pop.matrix} also deals with adults. The routines are 
primarily designed as internal service routines. }
\usage{ posum.pop.matrix(b,d,t0=0,point.wise=TRUE)

posum.death.matrix(b,d,fd)
}
%- maybe also `usage' for other objects documented here.
\arguments{
\item{b}{ A fitted \code{gam} object for a posum model with at least the extra 
variables \code{target.dt} and \code{model.type}.}
\item{d}{
A data frame defining the ages/times at which evaluation is required. It should 
contain variables:
   \item{a}{ array of ages at which evaluation is required.}
   \item{t}{ array of times at which evaluation required.}
   \item{juvenile}{by variable for juveniles.}
   \item{adult}{by variable for adults. }

The latter two are not always required.
}
\item{t0}{ The initial time (\code{posum.pop.matrix} only).}
\item{point.wise}{ If this is true then the surfaces at each age, time point are 
evaluated with spearate calls to \code{predict.gam}, which saves memory. If false 
then there is just one call to \code{predict.gam} with one large data frame: this 
is faster, but uses a large amount of memory. (\code{posum.pop.matrix} only).}
\item{fd}{ finite difference interval to use for obtaining death rates from 
type 1 models.}
}

\details{The required matrices are obtained by calls to \code{predict.gam()} 
which obtain matrices mapping parameters to evaluations of the model at particular 
age, time points. Appropriate quadrature formulae are then applied to the matrix 
rows. 
}
\value{ The functions return the required matrices.
}
\references{

Gu and Wahba (1991) Minimizing GCV/GML scores with multiple smoothing parameters 
via the Newton method. SIAM J. Sci. Statist. Comput. 12:383-398


Wood (2000) Modelling and Smoothing Parameter Estimation 
with Multiple Quadratic Penalties. JRSSB 62(2):413-428

Wood (2003) Thin Plate Regression Splines in press JRSSB
 
\url{http://www.ruwpa.st-and.ac.uk/simon.html}
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{} 

\seealso{   
\code{\link{posum}}
\code{\link{age.max}},
\code{\link{cm.splinefun}},
\code{\link{death.surface}},
\code{\link{hyman.filter}},
\code{\link{pcdr}},
\code{\link{population}},
\code{\link{population.data}},
\code{\link{population.surface}},
\code{\link{posum.atplot}},
\code{\link{posum.check}},
\code{\link{posum.con}},
\code{\link{posum.fit}},
\code{\link{posum.options}},
\code{\link{posum.plot}},
\code{\link{posum.stage}},
\code{\link{posum.stage.plot}},
\code{\link{posum.X}},
\code{\link{rec}},
\code{\link{sim.age.bound}},
\code{\link{spl.coef.conv}},
\code{\link{stage.bound}},
\code{\link{survival}},
}

\keyword{models} \keyword{smooth} \keyword{regression}%-- one or more ..






\name{posum.stage}
\alias{posum.stage}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Extract stage specific information from a fitted posum model}
\description{Given a fitted model object as returned by \code{posum}, this function integrates the 
fitted population and death rate surfaces over stages \code{lo} to \code{hi} inclusive, to produce 
rates averaged over stage(s) at each of the points in array \code{t}. If \code{aggregate} is \code{TRUE},
then integrated quantities over all elements of \code{t} are produced.  }
\usage{
posum.stage(x,lo=1,hi=lo,t=seq(min(x$data$t),max(x$data$t),length=100),
                      n.int=x$options$n.int,fdi=x$options$fdi,plot=TRUE,aggregate=FALSE)
}
%- maybe also `usage' for other objects documented here.
\arguments{
\item{x}{A fitted model object as produced by \code{posum}.}
\item{lo}{The stage at which to start integration}
\item{hi}{The stage at which to stop integration (if equal to \code{lo} then only one stage is 
integrated over).}
\item{t}{array of times at which to evaluate populations and death rates. If \code{aggregate==TRUE}
then this is an integration mesh.}
\item{n.int}{The number of age points to use in the integration over stages.}
\item{fdi}{The parameter controlling the finite difference interval used to evaluate death rates. The 
average spacing used in the integration mesh is found and then multiplied by this number to get the 
finite difference interval used for gradient estimation.}
\item{plot}{if \code{TRUE} then a plot is produced. }
\item{aggregate}{if \code{TRUE} then \code{t} is treated as an integration mesh, and rather than producing 
estimates for each time in \code{t}, integrated estimates are produced.}
}

\details{ All numerical inegration is by the trapezoidal rule. All evaluations use \code{predict.gam}. 
Standard errors are produced for all quantities, including per capita death rate (the latter se by 
local linearization).
}
\value{ A dataframe is returned with the following elements:
\item{p}{estimated population(s).}
\item{d}{estimated total death rate(s).}
\item{m}{estimated per capita death rate(s).}
\item{p.se}{standard error for \code{p}.}
\item{d.se}{standard error for \code{d}.}
\item{m.se}{standard error for \code{m}.}

}
\references{
\url{http://www.ruwpa.st-and.ac.uk/simon.html}
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{} 

\seealso{   
\code{\link{posum.atplot}},
\code{\link{posum.plot}},
\code{\link{posum.stage.plot}},
}

\examples{
data<-population.data(fam="p",adult=TRUE) #simulate data
b<-posum(data,fam="p")
r<-posum.stage(b,1,10,aggregate=TRUE)
old.pcdr<-pcdr;old.rec<-rec;old.sim.age.bound<-sim.age.bound
rec<-function(t) {50*exp(-0.5*(t-5)^2)}
pcdr<-function(a,t) {0.2231+a*0}
sim.age.bound<-function(stage,t) { (stage-1)+t*0}
data<-population.data(t=0:9,ns=9,sc=0,fam="n",adult=FALSE) #simulate data
b<-posum(data,fam="n")
r<-posum.stage(b,1,9,aggregate=TRUE)
pcdr<-old.pcdr;rec<-old.rec;sim.age.bound<-old.sim.age.bound
}
\keyword{models} \keyword{smooth} \keyword{regression}%-- one or more ..




\name{posum.stage.plot}
\alias{posum.stage.plot}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Stage specific posum fit plots}
\description{  produce stage specific plots from an object returned from 
posum(), if fit=FALSE then only the raw data is plotted.}

\usage{
posum.stage.plot(b,fit=TRUE)
}
%- maybe also `usage' for other objects documented here.
\arguments{
\item{b}{A fitted model object as returned from \code{posum}.}
\item{fit}{if this is \code{TRUE} then the raw data and fitted values are plotted, otherwise 
just the raw data.}
}
\details{ Produces one plot for each stage, but does not alter graphics parameters. Fitted values 
are joined up by lines, but not by the smooth curves implied by the fitted model.}

\value{ Simply produces plots.}

\references{
\url{http://www.ruwpa.st-and.ac.uk/simon.html}
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{} 

\seealso{   
\code{\link{posum.atplot}},
\code{\link{posum}},
\code{\link{posum.plot}},
\code{\link{posum.stage}},
}

\examples{
data<-population.data(fam="p",adult=TRUE) #simulate data
b<-posum(data,fam="p")
op<-par(mfrow=c(3,4))
posum.stage.plot(b)
rm(data,b)
par(op)
}
\keyword{models} \keyword{smooth} \keyword{regression}%-- one or more ..




\name{posum.surface}
\alias{posum.surface}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Evaluate a fitted population surface model.}
\description{ Produces data for plotting population or death surfaces for fitted
posum models, also produces the plot itself. }

\usage{ posum.surface(b,fdi=b$options$fdi,m=b$options$con.mesh,
type="p",plot=TRUE,con=FALSE,theta=60)
}
%- maybe also `usage' for other objects documented here.
\arguments{
\item{b}{ A fitted \code{gam} object for a posum model with at least the extra 
variables.}
\item{fdi}{multiplier used to control finite difference intervals when obtaining 
death rates for a type 1 model.}
\item{m}{data is returned on and \code{m} by \code{m} mesh.}
\item{type}{\code{"p"} for population, \code{"d"} for total death rate or 
\code{"m"} for per capita mortality. }
\item{plot}{\code{TRUE} if a plot should be produced.}
\item{con}{\code{TRUE} if plot should be a contour plot, otherwise a perspective
plot is shown.}
\item{theta}{angle for viewing perspective plot.}
}

\details{ Routine calls \code{posum.pop.matrix} and \code{posum.death.matrix} to do the real work.
}
\value{ A list with items \code{a}, \code{t} and \code{z} is returned, suitable 
for plotting with a call such as: \code{contour(as,ts,res$z)}
}
\references{

Gu and Wahba (1991) Minimizing GCV/GML scores with multiple smoothing parameters 
via the Newton method. SIAM J. Sci. Statist. Comput. 12:383-398


Wood (2000) Modelling and Smoothing Parameter Estimation 
with Multiple Quadratic Penalties. JRSSB 62(2):413-428

Wood (2003) Thin Plate Regression Splines in press JRSSB
 
\url{http://www.ruwpa.st-and.ac.uk/simon.html}
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{} 

\seealso{   
\code{\link{posum}}
\code{\link{age.max}},
\code{\link{cm.splinefun}},
\code{\link{death.surface}},
\code{\link{hyman.filter}},
\code{\link{pcdr}},
\code{\link{population}},
\code{\link{population.data}},
\code{\link{population.surface}},
\code{\link{posum.atplot}},
\code{\link{posum.check}},
\code{\link{posum.con}},
\code{\link{posum.fit}},
\code{\link{posum.options}},
\code{\link{posum.plot}},
\code{\link{posum.stage}},
\code{\link{posum.stage.plot}},
\code{\link{posum.X}},
\code{\link{rec}},
\code{\link{sim.age.bound}},
\code{\link{spl.coef.conv}},
\code{\link{stage.bound}},
\code{\link{survival}},
}

\keyword{models} \keyword{smooth} \keyword{regression}%-- one or more ..









\name{spl.coef.conv}
\alias{spl.coef.conv}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Convert Hermite spline coefficients to simple power basis coefficients.}
\description{ Takes the knot locations and gradients at knots, specifying a piecewise cubic 
interpolant using cubic Hermite polynomials, and calculates the coefficients of the piecewise 
polynomials expressed using a simple power basis. }
\usage{
spl.coef.conv(z)
}
%- maybe also `usage' for other objects documented here.
\arguments{
\item{z}{A data frame or list containing at least:
   \item{x,y}{x,y points being interpolated by piecewise cubic function of x 
               (continuous to at least first derivative).}
   \item{b}{ gradients of piecewise cubic w.r.t. x at each supplied x value - this with 
        \code{x,y} is sufficient to determine the piecewise cubic polynomial through the data.}
 }
}

\details{ \code{x,y,b} are sufficient to uniquely define a C1 piecewise cubic interpolant of the
\code{x,y} data, using cubic Hermite polynomials, however many routines use the polynomial power 
basis, and in this case 2 extra coefficients need to be calcualted at each \code{x} value - the 
values of the second and third deriatives of the function, \code{c} and \code{d}, respectively. 
This routine does this. Its primary function is to take a Hyman filtered spline based interpolant 
and obtain the coefficients to enable this to be evaluated using code supplied in the R base package.
}
\value{ The function returns \code{z} with new \code{c} and \code{d} arrays.
}
\references{
\url{http://www.ruwpa.st-and.ac.uk/simon.html}
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{} 

\seealso{   
\code{\link{cm.splinefun}},
\code{\link{hyman.filter}},
}

\examples{
x<-0:9
y<-c(0,0,2,2,4,4,5,6,7,7)
normal.spl<-splinefun(x,y)
xx<-seq(0,9,length=100)
plot(xx,normal.spl(xx),type="l",col=2,main="Hyman filter demonstration")
n<-length(y)
z <- .C("spline_coef", method = as.integer(2), n = n, 
        x = as.double(x), y = as.double(y), b = double(n), c = double(n), 
        d = double(n),e = double(0), PACKAGE = "base")
z<-hyman.filter(z) # filter gradients for co-monotonicity
z<-spl.coef.conv(z) # force other coefficients to consistency
cm.spl<-function(x) { .C("spline_eval", z$method, length(x), x = as.double(x), 
            y = double(length(x)), z$n, z$x, z$y, z$b, z$c, z$d, 
            PACKAGE = "base")$y}
lines(xx,cm.spl(xx),col=3)
points(x,y)

}
\keyword{models} \keyword{smooth} \keyword{regression}%-- one or more ..




\name{stage.bound}
\alias{stage.bound}
\title{Extract stage boundary information from posum objects}
\description{Takes and input or output posum data object and extracts
the stage boundary information from this, returning a function giving
the boundary as a function of time, which interpolates the extracted 
boundary data and meets the biological constraint that its time derivative 
is always less than or equal to 1.}

\usage{
stage.bound(x,stage,low=TRUE)
}
%- maybe also `usage' for other objects documented here.
\arguments{
\item{x}{A data frame containing the following named variables:
   \item{y}{The stage population data. This may contain \code{NA}'s: 
            a feature whose prime function is to allow the user to 
            supply extra information about stage boundaries, if
            needed.}
   \item{stage}{Which stage each element of \code{y} relates to.}
   \item{a0}{The lower age boundary for this observation.}
   \item{a1}{The upper age boundary for this observation. \code{NA} 
             implies an adult stage. If an element is equal to the
             corresponding \code{a0} element then the corresponding
             \code{y} is taken as a direct observation of the population
             surface height (rather than the usual integral under it.)}
   \item{t}{Sample time for each observation.}
}
 \item{stage}{The stage for which the age boundary function is required.}
\item{low}{\code{TRUE} if a lower boundary is required, \code{FALSE} for an upper boundary.}
}

\details{ All \code{a0} or \code{a1} records are extracted for the relevant 
stage, along with their corresponding \code{t} records. After some checks, 
these data are then interpolated using \code{cm.splinefun}, which fits a 
cubic interpolating spline and then filters its coefficients it to ensure that 
its time derivative is never greater than 1. The resulting filtered 
interpolating function is then returned.
}
\value{ An interpolating function of time.
}
\references{
\url{http://www.ruwpa.st-and.ac.uk/simon.html}
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{} 

\seealso{   
\code{\link{age.max}},
\code{\link{cm.splinefun}},
\code{\link{hyman.filter}},
\code{\link{posum.atplot}},
\code{\link{spl.coef.conv}},
}

\examples{
data<-population.data(fam="p",adult=TRUE) #simulate data
bound3<-stage.bound(data,3,low=TRUE)
time<-0:100
plot(time,bound3(time),type="l",
main="Simulated data stage 3 lower age boundary")
}
\keyword{models} \keyword{smooth} \keyword{regression}%-- one or more ..




\name{Simulating posum data}
\alias{population}
\alias{survival}

\title{Population Surface Model Simulation}
\description{ These routines are for numerically integrating the McKendrick equation to obtain
population per unit age interval from the per capita death rates and recruitment rates specified
in \code{rec} and \code{pcdr}. \code{survival(a,t)} finds the proportion surviving from birth to age 
a, t, while \code{population(a,t)} finds the populaiton per unit age interval at a, t using \code{rec} 
and \code{survival}.}
\usage{
survival(a,t)

population(a,t)
}
%- maybe also `usage' for other objects documented here.
\arguments{
\item{a}{ age survived to or at which population is required.}
\item{t}{ time survived to or at which population is required.}
}

\details{ Survival is the negative exponential of the integral of per capiat death rate 
from recruitment to a, t. The integral is performed numerically using the trapezoidal rule.
The population per unit age interval at a,t  is just the product of the recruitment rate at 
t-a and the survival to a, t. Note that these functions do not operate on arrays.
}
\value{ Returns the proportion surviving, or the population per unit age interval.
}
\references{
\url{http://www.ruwpa.st-and.ac.uk/simon.html}
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{} 

\seealso{   
\code{\link{death.surface}},
\code{\link{pcdr}},
\code{\link{population.data}},
\code{\link{population.surface}},
\code{\link{rec}},
\code{\link{sim.age.bound}},
}

\examples{
m<-30;a1<-30;t1<-100
pop<-matrix(0,m,m)
da<-a1/(m-1);dt<-t1/(m-1)
t<-a<-0:(m-1);a<-a*da;t<-t*dt
for (i in 1:m) for (j in 1:m) pop[i,j]<-population(a[i],t[j])
contour(a,t,pop,xlab="a",ylab="t") 
}
\keyword{models} \keyword{smooth} \keyword{regression}%-- one or more ..




